====================
Quickstart Tutorial
====================

Installation:

.. code-block:: bash

   pip install mfw-template


Creating a new project:

.. code-block:: bash

   mfw-template create-project

Adding new resource type into project:

.. code-block:: bash

   cd $PROJECT
   mfw-template create-resource

